@@ -32,6 +32,7 @@ describe 'aodh' do
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
           :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
@@ -47,32 +48,25 @@ describe 'aodh' do
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
-        )
-        is_expected.to contain_oslo__messaging__amqp('aodh_config').with(
-          :server_request_prefix => '<SERVICE DEFAULT>',
-          :broadcast_prefix      => '<SERVICE DEFAULT>',
-          :group_request_prefix  => '<SERVICE DEFAULT>',
-          :container_name        => '<SERVICE DEFAULT>',
-          :idle_timeout          => '<SERVICE DEFAULT>',
-          :trace                 => '<SERVICE DEFAULT>',
-          :ssl_ca_file           => '<SERVICE DEFAULT>',
-          :ssl_cert_file         => '<SERVICE DEFAULT>',
-          :ssl_key_file          => '<SERVICE DEFAULT>',
-          :sasl_mechanisms       => '<SERVICE DEFAULT>',
-          :sasl_config_dir       => '<SERVICE DEFAULT>',
-          :sasl_config_name      => '<SERVICE DEFAULT>',
-          :username              => '<SERVICE DEFAULT>',
-          :password              => '<SERVICE DEFAULT>',
+          :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
+          :use_queue_manager               => '<SERVICE DEFAULT>',
+          :hostname                        => '<SERVICE DEFAULT>',
+          :processname                     => '<SERVICE DEFAULT>',
+          :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__notifications('aodh_config').with(
           :transport_url => '<SERVICE DEFAULT>',
           :driver        => '<SERVICE DEFAULT>',
-          :topics        => '<SERVICE DEFAULT>'
+          :topics        => '<SERVICE DEFAULT>',
+          :retry         => '<SERVICE DEFAULT>',
         )
       end
 
       it 'configures other parameters' do
         is_expected.to contain_aodh_config('database/alarm_history_time_to_live').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__concurrency('aodh_config').with(
+          :lock_path => '<SERVICE DEFAULT>'
+        )
       end
 
       it 'passes purge to resource' do
@@ -93,6 +87,7 @@ describe 'aodh' do
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :rabbit_heartbeat_in_pthread        => true,
+          :rabbit_qos_prefetch_count          => 0,
           :kombu_reconnect_delay              => '5.0',
           :amqp_durable_queues                => true,
           :kombu_compression                  => 'gzip',
@@ -106,18 +101,18 @@ describe 'aodh' do
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
-          :amqp_idle_timeout                  => '60',
-          :amqp_trace                         => true,
-          :amqp_ssl_ca_file                   => '/etc/ca.cert',
-          :amqp_ssl_cert_file                 => '/etc/certfile',
-          :amqp_ssl_key_file                  => '/etc/key',
-          :amqp_username                      => 'amqp_user',
-          :amqp_password                      => 'password',
+          :rabbit_enable_cancel_on_failover   => false,
+          :rabbit_use_queue_manager           => false,
+          :rabbit_hostname                    => 'node1.example.com',
+          :rabbit_processname                 => 'procname',
+          :rabbit_stream_fanout               => false,
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                => 'ceilometer.compute.aodh_notifier',
           :notification_topics                => 'openstack',
+          :notification_retry                 => 10,
           :package_ensure                     => '2012.1.1-15.el6',
           :alarm_history_time_to_live         => '604800',
+          :lock_path                          => '/var/lock/aodh',
         }
       end
 
@@ -133,6 +128,7 @@ describe 'aodh' do
           :heartbeat_timeout_threshold     => '60',
           :heartbeat_rate                  => '10',
           :heartbeat_in_pthread            => true,
+          :rabbit_qos_prefetch_count       => 0,
           :kombu_reconnect_delay           => '5.0',
           :amqp_durable_queues             => true,
           :kombu_compression               => 'gzip',
@@ -146,25 +142,25 @@ describe 'aodh' do
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
-        )
-        is_expected.to contain_oslo__messaging__amqp('aodh_config').with(
-          :idle_timeout  => '60',
-          :trace         => true,
-          :ssl_ca_file   => '/etc/ca.cert',
-          :ssl_cert_file => '/etc/certfile',
-          :ssl_key_file  => '/etc/key',
-          :username      => 'amqp_user',
-          :password      => 'password',
+          :enable_cancel_on_failover       => false,
+          :use_queue_manager               => false,
+          :hostname                        => 'node1.example.com',
+          :processname                     => 'procname',
+          :rabbit_stream_fanout            => false,
         )
         is_expected.to contain_oslo__messaging__notifications('aodh_config').with(
           :transport_url => 'rabbit://rabbit_user:password@localhost:5673',
           :driver        => 'ceilometer.compute.aodh_notifier',
           :topics        => 'openstack',
+          :retry         => 10,
         )
       end
 
       it 'configures other parameters' do
         is_expected.to contain_aodh_config('database/alarm_history_time_to_live').with_value('604800')
+        is_expected.to contain_oslo__concurrency('aodh_config').with(
+          :lock_path => '/var/lock/aodh'
+        )
       end
 
     end
